#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ARG_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ARG_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/arg.hpp>

#endif
